@@ -177,28 +177,39 @@ class WebDriver(webdriver.Remote):
         :Args:
          - positions - an array of tuples representing the x/y coordinates of
          the fingers to tap. Length can be up to five.
-         - duration - (optional) length of time to tap, in seconds
+         - duration - (optional) length of time to tap, in ms
 
         :Usage:
             driver.tap([(100, 20), (100, 60), (100, 100)], 500)
         """
-        ma = MultiAction(self)
-        for position in positions:
-            x = position[0]
-            y = position[1]
+        if len(positions) == 1:
             action = TouchAction(self)
+            x = positions[0][0]
+            y = positions[0][1]
             if duration:
-                duration = duration * 1000 # we take seconds, but send milliseconds
+                duration = duration
                 action.long_press(x=x, y=y, duration=duration).release()
             else:
                 action.press(x=x, y=y).release()
-            ma.add(action)
+            action.perform()
+        else:
+            ma = MultiAction(self)
+            for position in positions:
+                x = position[0]
+                y = position[1]
+                action = TouchAction(self)
+                if duration:
+                    duration = duration * 1000 # we take seconds, but send milliseconds
+                    action.long_press(x=x, y=y, duration=duration).release()
+                else:
+                    action.press(x=x, y=y).release()
+                ma.add(action)
 
-        ma.perform()
+            ma.perform()
         return self
 
     # convenience method added to Appium (NOT Selenium 3)
-    def swipe(self, startx, starty, endx, endy, duration=0):
+    def swipe(self, startx, starty, endx, endy, duration=None):
         """Swipe from one point to another point, for an optional duration.
 
         :Args:
@@ -206,7 +217,7 @@ class WebDriver(webdriver.Remote):
          - starty - y-coordinate at which to end
          - endx - x-coordinate at which to stop
          - endy - y-coordinate at which to stop
-         - duration - (optional) time to take the swipe, in seconds.
+         - duration - (optional) time to take the swipe, in ms.
 
         :Usage:
             driver.swipe(100, 100, 100, 400)
@@ -223,7 +234,28 @@ class WebDriver(webdriver.Remote):
         return self
 
     # convenience method added to Appium (NOT Selenium 3)
-    def pinch(self, element=None, startx=None, starty=None, endx=None, endy=None, duration=None):
+    def flick(self, startx, starty, endx, endy):
+        """Flick from one point to another point.
+
+        :Args:
+         - startx - x-coordinate at which to start
+         - starty - y-coordinate at which to end
+         - endx - x-coordinate at which to stop
+         - endy - y-coordinate at which to stop
+
+        :Usage:
+            driver.flick(100, 100, 100, 400)
+        """
+        action = TouchAction(self)
+        action \
+            .press(x=startx, y=starty) \
+            .move_to(x=endx, y=endy) \
+            .release()
+        action.perform()
+        return self
+
+    # convenience method added to Appium (NOT Selenium 3)
+    def pinch(self, element=None, percent=200, steps=50):
         """Pinch on an element a certain amount
 
         :Args:
@@ -239,19 +271,14 @@ class WebDriver(webdriver.Remote):
 
         opts = {
             'element': element,
-            'startX': startx,
-            'startY': starty,
-            'endX': endx,
-            'endY': endy,
-            'duration': duration
+            'percent': percent,
+            'steps': steps
         };
         self.execute_script('mobile: pinchClose', opts)
         return self
 
     # convenience method added to Appium (NOT Selenium 3)
-    # {startX: 114.0, startY: 198.0, endX: 257.0,
-    #       endY: 256.0, duration: 5.0}
-    def zoom(self, element=None, startx=None, starty=None, endx=None, endy=None, duration=None):
+    def zoom(self, element=None, percent=200, steps=50):
         """Zooms in on an element a certain amount
 
         :Args:
@@ -267,11 +294,8 @@ class WebDriver(webdriver.Remote):
 
         opts = {
             'element': element,
-            'startX': startx,
-            'startY': starty,
-            'endX': endx,
-            'endY': endy,
-            'duration': duration
+            'percent': percent,
+            'steps': steps
         };
         self.execute_script('mobile: pinchOpen', opts)
         return self
